structure(list(method = "GET", url = "/stream?logical-path=%2FtempZone%2Fhome%2Frods%2Ftestthat%2Fdfr.csv&offset=0&count=2000", 
    status_code = 200L, headers = structure(list(Server = "nginx/1.23.1", 
        Date = "Sun, 29 Oct 2023 09:45:33 GMT", `Content-Length` = "24", 
        Connection = "keep-alive", `Access-Control-Allow-Origin` = "*", 
        `Access-Control-Allow-Headers` = "*", `Access-Control-Allow-Methods` = "AUTHORIZATION,ACCEPT,GET,POST,OPTIONS,PUT,DELETE"), class = "httr2_headers"), 
    body = as.raw(c(0x61, 0x2c, 0x62, 0x2c, 0x63, 0x0a, 0x61, 
    0x2c, 0x31, 0x2c, 0x36, 0x0a, 0x62, 0x2c, 0x32, 0x2c, 0x37, 
    0x0a, 0x63, 0x2c, 0x33, 0x2c, 0x38, 0x0a))), class = "httr2_response")
